@@ -1,3 +1,3 @@
-rm -rf dist
+rm -rf dist KB4IT.egg-info build
 python3 setup.py sdist bdist_wheel
 python3 -m twine upload --repository-url https://test.pypi.org/legacy/ dist/*
